pub struct Ref<'a, T: 'a> { /* private fields */ }Implementations
Sourceimpl<'a, T: 'a> Ref<'a, T>
impl<'a, T: 'a> Ref<'a, T>
pub fn new(borrow: Shared<'a>, value: &'a T) -> Self
pub fn map_into<K: 'a, F: FnMut(&'a T) -> K>(self, f: F) -> RefMap<'a, K>
pub fn map<K: 'a, F: FnMut(&T) -> &K>(&self, f: F) -> Ref<'a, K>
Sourcepub unsafe fn deconstruct(self) -> (Shared<'a>, &'a T)
pub unsafe fn deconstruct(self) -> (Shared<'a>, &'a T)
Deconstructs this mapped borrow to its underlying borrow state and value.
Safety
Ensure that you still follow all safety guidelines of this mapped ref.