pub struct RefMapMut<'a, T: 'a> { /* private fields */ }Implementations
Sourceimpl<'a, T: 'a> RefMapMut<'a, T>
impl<'a, T: 'a> RefMapMut<'a, T>
pub fn new(borrow: Exclusive<'a>, value: T) -> Self
pub fn map_into<K: 'a, F: FnMut(&mut T) -> K>(self, f: F) -> RefMapMut<'a, K>
Sourcepub unsafe fn deconstruct(self) -> (Exclusive<'a>, T)
pub unsafe fn deconstruct(self) -> (Exclusive<'a>, T)
Deconstructs this mapped borrow to its underlying borrow state and value.
Safety
Ensure that you still follow all safety guidelines of this mutable mapped ref.