pub struct Chunk<'a, V: for<'b> View<'b>> { /* private fields */ }Expand description
A type-safe view of a chunk of entities all of the same data layout.
Implementations
Sourceimpl<'a, V: for<'b> View<'b>> Chunk<'a, V>
impl<'a, V: for<'b> View<'b>> Chunk<'a, V>
pub fn new( archetype: &'a ArchetypeData, set_index: SetIndex, chunk_index: ChunkIndex, ) -> Self
Sourcepub fn iter_mut(&mut self) -> <V as View<'a>>::Iter
pub fn iter_mut(&mut self) -> <V as View<'a>>::Iter
Get an iterator of all data contained within the chunk.
Sourcepub fn iter_entities_mut(&mut self) -> ZipEntities<'a, V> ⓘ
pub fn iter_entities_mut(&mut self) -> ZipEntities<'a, V> ⓘ
Get an iterator of all data and entity IDs contained within the chunk.