pub struct Storage { /* private fields */ }Expand description
Stores all entity data for a World.
Implementations
Sourceimpl Storage
impl Storage
pub fn new(world_id: WorldId) -> Self
Sourcepub fn component_types(&self) -> &ComponentTypes
pub fn component_types(&self) -> &ComponentTypes
Gets a vector of slices of all component types for all archetypes.
Each slice contains the component types for the archetype at the corresponding index.
Sourcepub fn tag_types(&self) -> &TagTypes
pub fn tag_types(&self) -> &TagTypes
Gets a vector of slices of all tag types for all archetypes.
Each slice contains the tag types for the archetype at the corresponding index.
Sourcepub fn archetypes(&self) -> &[ArchetypeData]
pub fn archetypes(&self) -> &[ArchetypeData]
Gets a slice reference to all archetypes.
Sourcepub fn archetypes_mut(&mut self) -> &mut [ArchetypeData]
pub fn archetypes_mut(&mut self) -> &mut [ArchetypeData]
Gets a mutable slice reference to all archetypes.