pub struct StorageAccessor<'a> { /* private fields */ }Implementations
Sourceimpl<'a> StorageAccessor<'a>
impl<'a> StorageAccessor<'a>
pub fn new(storage: &'a Storage, archetypes: Option<&'a BitSet>) -> Self
pub fn can_access_archetype(&self, ArchetypeIndex: ArchetypeIndex) -> bool
pub fn inner(&self) -> &'a Storage
pub fn into_inner(self) -> &'a Storage
Methods from Deref<Target = Storage>
Sourcepub fn component_types(&self) -> &ComponentTypes
pub fn component_types(&self) -> &ComponentTypes
Gets a vector of slices of all component types for all archetypes.
Each slice contains the component types for the archetype at the corresponding index.
Sourcepub fn tag_types(&self) -> &TagTypes
pub fn tag_types(&self) -> &TagTypes
Gets a vector of slices of all tag types for all archetypes.
Each slice contains the tag types for the archetype at the corresponding index.
Sourcepub fn archetypes(&self) -> &[ArchetypeData]
pub fn archetypes(&self) -> &[ArchetypeData]
Gets a slice reference to all archetypes.