SubWorld

Struct SubWorld 

pub struct SubWorld<'a> { /* private fields */ }
Provides access to a subset of the entities of a World.

Implementations

Source

impl<'a> SubWorld<'a>

pub unsafe fn new_unchecked( world: &'a World, access: &'a Permissions<ComponentTypeId>, archetypes: &'a ArchetypeAccess, ) -> Self

Constructs a new SubWorld.

Safety

Queries assume that this type has been constructed correctly. Ensure that sub-worlds represent disjoint portions of a world and that the world is not used while any of its sub-worlds are alive.

pub fn split<'b, T: for<'v> View<'v>>( &'b mut self, ) -> (SubWorld<'b>, SubWorld<'b>)
where 'a: 'b,

Splits the world into two. The left world allows access only to the data declared by the view; the right world allows access to all else.

pub fn split_for_query<'q, V: for<'v> View<'v>, F: EntityFilter>( &mut self, _: &'q Query<V, F>, ) -> (SubWorld<'_>, SubWorld<'_>)

Splits the world into two. The left world allows access only to the data declared by the query’s view; the right world allows access to all else.