pub struct HashMapEntityReplacePolicy<'m>(pub &'m HashMap<Entity, Entity>);Expand description
Default implementation of EntityReplacePolicy that uses a hash map. Keys are entities in the
source world and values are entities in the destination world. (See comments on
EntityReplacePolicy)
Tuple Fields
0: &'m HashMap<Entity, Entity>Trait Implementations
Sourceimpl<'m, 's> EntityReplacePolicy<'s> for HashMapEntityReplacePolicy<'m>
impl<'m, 's> EntityReplacePolicy<'s> for HashMapEntityReplacePolicy<'m>
Sourcefn src_entities<'a>(&'s self) -> Box<dyn Iterator<Item = Entity> + 'a>where
's: 'a,
fn src_entities<'a>(&'s self) -> Box<dyn Iterator<Item = Entity> + 'a>where
's: 'a,
Returns all entities in the source world that will replace data in the destination world Read more