pub struct AtomicRefCell<T> { /* private fields */ }Expand description
A RefCell implementation which is thread safe. This type performs all the standard runtime
borrow checking which would be familiar from using RefCell.
UnsafeCell is used in this type, but borrow checking is performed using atomic values,
garunteeing safe access across threads.
Safety
Runtime borrow checking is only conducted in builds with debug_assertions enabled. Release
builds assume proper resource access and will cause undefined behavior with improper use.
Implementations
Sourceimpl<T> AtomicRefCell<T>
impl<T> AtomicRefCell<T>
pub fn new(value: T) -> Self
Sourcepub fn get(&self) -> Ref<'_, T>
pub fn get(&self) -> Ref<'_, T>
Retrieve an immutable Ref wrapped reference of &T.
Panics
This method panics if this value is already mutably borrowed.
Safety
Runtime borrow checking is only conducted in builds with debug_assertions enabled. Release
builds assume proper resource access and will cause undefined behavior with improper use.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Unwrap the value from the RefCell and kill it, returning the value.
Sourcepub fn try_get(&self) -> Result<Ref<'_, T>, String>
pub fn try_get(&self) -> Result<Ref<'_, T>, String>
Retrieve an immutable Ref wrapped reference of &T. This is the safe version of get
providing an error result on failure.
Returns
Some(T) if the value can be retrieved.
Err if the value is already mutably borrowed.
Sourcepub fn get_mut(&self) -> RefMut<'_, T>
pub fn get_mut(&self) -> RefMut<'_, T>
Retrieve an mutable RefMut wrapped reference of &mut T.
Panics
This method panics if this value is already mutably borrowed.
Safety
Runtime borrow checking is only conducted in builds with debug_assertions enabled. Release
builds assume proper resource access and will cause undefined behavior with improper use.
Sourcepub fn try_get_mut(&self) -> Result<RefMut<'_, T>, String>
pub fn try_get_mut(&self) -> Result<RefMut<'_, T>, String>
Retrieve a mutable RefMut wrapped reference of &mut T. This is the safe version of
get_mut providing an error result on failure.
Returns
Some(T) if the value can be retrieved.
Err if the value is already mutably borrowed.
Safety
This release version of this function does not perform runtime borrow checking and will cause undefined behavior if borrow rules are violated. This means they should be enforced on the use of this type.